@@ -260,7 +260,7 @@ def _create_db_operand_aarch64(operand):
 
 def _create_db_operand_x86(operand):
     """Get DB operand for AArch64 by operand string."""
-    if operand == "r":
+    if operand.startswith("r"):
         return {"class": "register", "name": "gpr"}
     elif operand in "xyz":
         return {"class": "register", "name": operand + "mm"}
@@ -615,7 +615,7 @@ def _get_full_instruction_name(instruction_form):
 
 def __represent_none(self, data):
     """Get YAML None representation."""
-    return self.represent_scalar(u"tag:yaml.org,2002:null", u"~")
+    return self.represent_scalar("tag:yaml.org,2002:null", "~")
 
 
 def _create_yaml_object():
