@@ -132,8 +132,8 @@ class ParserAArch64(BaseParser):
                 pp.Literal(".")
                 + pp.Optional(pp.Word("12468")).setResultsName("lanes")
                 + pp.Word(pp.alphas, exact=1).setResultsName("shape")
-                + pp.Optional(index)
             )
+            + pp.Optional(index)
         )
         predicate = (
             pp.CaselessLiteral("p").setResultsName("prefix")
@@ -196,11 +196,34 @@ class ParserAArch64(BaseParser):
                 "policy"
             )
         ).setResultsName("prfop")
+        # Condition codes, based on http://tiny.cc/armcc
+        condition = (
+            pp.CaselessLiteral("EQ")  # z set
+            ^ pp.CaselessLiteral("NE")  # z clear
+            ^ pp.CaselessLiteral("CS")  # c set
+            ^ pp.CaselessLiteral("HS")  # c set
+            ^ pp.CaselessLiteral("CC")  # c clear
+            ^ pp.CaselessLiteral("LO")  # c clear
+            ^ pp.CaselessLiteral("MI")  # n set
+            ^ pp.CaselessLiteral("PL")  # n clear
+            ^ pp.CaselessLiteral("VS")  # v set
+            ^ pp.CaselessLiteral("VC")  # v clear
+            ^ pp.CaselessLiteral("HI")  # c set and z clear
+            ^ pp.CaselessLiteral("LS")  # c clear or z set
+            ^ pp.CaselessLiteral("GE")  # n and v the same
+            ^ pp.CaselessLiteral("LT")  # n and v different
+            ^ pp.CaselessLiteral("GT")  # z clear, and n and v the same
+            ^ pp.CaselessLiteral("LE")  # z set, or n and v different
+            ^ pp.CaselessLiteral("AL")  # any
+        ).setResultsName("condition")
+        self.condition = condition
         # Combine to instruction form
         operand_first = pp.Group(
             register ^ (prefetch_op | immediate) ^ memory ^ arith_immediate ^ identifier
         )
-        operand_rest = pp.Group((register ^ immediate ^ memory ^ arith_immediate) | identifier)
+        operand_rest = pp.Group(
+            (register ^ condition ^ immediate ^ memory ^ arith_immediate) | identifier
+        )
         self.instruction_parser = (
             mnemonic
             + pp.Optional(operand_first.setResultsName("operand1"))
@@ -510,15 +533,12 @@ class ParserAArch64(BaseParser):
 
     def get_full_reg_name(self, register):
         """Return one register name string including all attributes"""
-        if "lanes" in register:
-            return (
-                register["prefix"]
-                + str(register["name"])
-                + "."
-                + str(register["lanes"])
-                + register["shape"]
-            )
-        return register["prefix"] + str(register["name"])
+        name = register["prefix"] + str(register["name"])
+        if "shape" in register:
+            name += "." + str(register.get("lanes", "")) + register["shape"]
+        if "index" in register:
+            name += "[" + register["index"] + "]"
+        return name
 
     def normalize_imd(self, imd):
         """Normalize immediate to decimal based representation"""
@@ -561,7 +581,7 @@ class ParserAArch64(BaseParser):
         """Check if ``flag_a`` is dependent on ``flag_b``"""
         # we assume flags are independent of each other, e.g., CF can be read while ZF gets written
         # TODO validate this assumption
-        if flag_a.name == flag_b.name:
+        if flag_a["name"] == flag_b["name"]:
             return True
         return False
 
