@@ -22,10 +22,10 @@ class ParserX86ATT(BaseParser):
         self.isa = "x86"
 
     def construct_parser(self):
-        """Create parser for ARM AArch64 ISA."""
-        decimal_number = pp.Combine(pp.Optional(pp.Literal("-")) + pp.Word(pp.nums)).setResultsName(
-            "value"
-        )
+        """Create parser for x86 AT&T ISA."""
+        decimal_number = pp.Combine(
+            pp.Optional(pp.Literal("-")) + pp.Word(pp.nums)
+        ).setResultsName("value")
         hex_number = pp.Combine(
             pp.Optional(pp.Literal("-")) + pp.Literal("0x") + pp.Word(pp.hexnums)
         ).setResultsName("value")
@@ -36,12 +36,13 @@ class ParserX86ATT(BaseParser):
         # Define x86 assembly identifier
         relocation = pp.Combine(pp.Literal("@") + pp.Word(pp.alphas))
         id_offset = pp.Word(pp.nums) + pp.Suppress(pp.Literal("+"))
-        first = pp.Word(pp.alphas + "_.", exact=1)
+        first = pp.Word(pp.alphas + "-_.", exact=1)
         rest = pp.Word(pp.alphanums + "$_.+-")
         identifier = pp.Group(
             pp.Optional(id_offset).setResultsName("offset")
             + pp.Combine(
-                pp.delimitedList(pp.Combine(first + pp.Optional(rest)), delim="::"), joinString="::"
+                pp.delimitedList(pp.Combine(first + pp.Optional(rest)), delim="::"),
+                joinString="::",
             ).setResultsName("name")
             + pp.Optional(relocation).setResultsName("relocation")
         ).setResultsName("identifier")
@@ -88,7 +89,7 @@ class ParserX86ATT(BaseParser):
         ).setResultsName(self.IMMEDIATE_ID)
 
         # Memory preparations
-        offset = pp.Group(identifier | hex_number | decimal_number).setResultsName(
+        offset = pp.Group(hex_number | decimal_number | identifier).setResultsName(
             self.IMMEDIATE_ID
         )
         scale = pp.Word("1248", exact=1)
@@ -443,7 +444,12 @@ class ParserX86ATT(BaseParser):
         """Check if register is a vector register"""
         if register is None:
             return False
-        if register["name"].rstrip(string.digits).lower() in ["mm", "xmm", "ymm", "zmm"]:
+        if register["name"].rstrip(string.digits).lower() in [
+            "mm",
+            "xmm",
+            "ymm",
+            "zmm",
+        ]:
             return True
         return False
 
